=======
History
=======

1.4.3 (2018-03-21)
------------------

* Fixed issue #23: Print a warning when no match is found in controlled files
* Fixed issue #27: Possible typo in docs
* Fixed issue #29: punch silently adds and commits unrelated untracked files to git

1.4.2 (2017-10-05)
------------------

* Fixed error with months and days ending with 0

1.4.1 (2017-09-16)
------------------

* Minor fixes to the date part representation

1.4.0 (2017-06-07)
------------------

* Support for actions to specify complex behaviours
* PEP8 compliance global review

1.3.2 (2017-03-29)
------------------

* Fixed CLI script installation on Windows (by jobec)

1.3.1 (2017-01-23)
------------------

* Readthedocs documentation link added to README

1.3.0 (2017-01-20)
------------------

* Date-base version part added (with support for CalVer syntax)

1.2.0 (2016-09-09)
------------------

* Mercurial support added by Michele D'Amico

1.1.2 (2016-06-09)
------------------

* Fixed issue #7

1.1.1 (2016-06-01)
------------------

* Fixed issues #3, #4, #5

1.1.0 (2016-05-26)
------------------

* Added --set-part and --reset-on-set flags

1.0.2 (2016-05-24)
------------------

* Fixed the PyPI badge in the documentation
* Added some examples both in documentation and in the test suite

1.0.1 (2016-05-21)
------------------

* Last minute change of package name on PyPI due to a name clash.

1.0.0 (2016-05-19)
------------------

* First release on PyPI.
